require 'tk'
require_relative 'guide'

class Gui
#A class which uses Tcl/Tk to build a GUI for user interaction
#_______________________________________________
#we start by building a Toplevel Help window which is used by a menu as a Help guide
def self.help_win
$win = TkToplevel.new{title "Help Window"}
$scrollbar = TkScrollbar.new($win){command proc{|*args| $textwin.yview(*args)}
}.pack('side' => 'right', 'fill' => 'y')
$textwin =TkText.new($win){
  borderwidth 1
  wrap 'word'
  font TkFont.new('times 14 bold')
  background  "yellow"
  pack('side' => 'left')
}
$guide = Guide.view
$textwin.insert(1.0, "#{$guide}")
$textwin.yscrollcommand(proc{|first, last| $scrollbar.set(first, last)})
end
#_______________________________________________________
#method to build the root main window
def self.root
TkRoot.new{
title "#$title"
}
end
#_______________________________________________________
#method to draw a label with text (lbltxt) and coordinates x,y in a grid
def self.label(lbltxt, x,y)
  TkLabel.new(root){
    text "#{lbltxt}"
    grid('row' => x, 'column' => y, 'padx' => 10, 'pady' => 15)}
end
#_______________ HEADER _________________________________
def self.header(hdtxt, x, y)
 TkLabel.new(root){
    text "#{hdtxt}"
    background "green"
    borderwidth 4
    font TkFont.new('Proxima 16 bold')
    foreground  "black"
    'padx' '10'
    'pady' '15'
    justify "center"
    relief 'raised'
    grid('rowspan' => x, 'columnspan' => y, 'padx' => 10, 'pady' => 15)}
end
#________________________________________________________
#method to draw a button with text (btntxt), triggering method (m) and coordinates x,y
def self.button(btntxt, m, x,y)
   TkButton.new(root){
   text  "#{btntxt}"
   command(m)
   grid('row' => x, 'column' => y, 'padx' => 10, 'pady' => 15)}
end

#________________________________________________________
#method to draw an entry field sending value to variable (var)[ use $var1 to $var3]
def self.entry(var, x, y)
  TkEntry.new(root){
    textvariable var
   grid('row' => x, 'column' => y, 'padx' => 10, 'pady' => 15)}
end
#_____________________________________________________________
#method to draw a textfield with specific width (w), height (h), background color (bg)
#and foreground color (fg), and coordinates x, y, with vertical scrollbar
def self.textfield(w, h, x, y)
  $textfield = TkText.new(root){
    width w
    height h
    background "black"
    foreground  "white"
    font TkFont.new('times 14 bold')
    grid('rowspan' => x, 'columnspan' => y, 'padx' => 10, 'pady' => 15)
	}
end	
#____________________________________________________________	
#The Scrollbar to use with textfield widget
def scroll
$scroll = TkScrollbar.new{command proc{|*args|
    $textfield.yview(*args)
	$textfield.yscrollcommand(proc {|first, last| $scroll.set(first, last)})
    pack('side' => 'right', 'fill' => 'y')}
	}
end
#______________ MENU _______________________________________________
def self.menu
#No tearoff marker
TkOption.add '*tearOff', 0
#____________________ METHODS _____________________________
#________________CLEAR TEXTFIELD ___________________________
newfile = Proc.new{$textfield.delete(1.0, 'end')}
#______________ OPEN DIRECTORY _____________________________
opendir = Proc.new{
$dir = Tk::chooseDirectory
$file_list = []
$file_list = Dir.entries($dir).select {|f| !File.directory? f}
$files = $file_list.join("\n")
$textfield.delete(1.0, 'end')
$textfield.insert('end', "#$files")
}
#___________________________________
exitapp = Proc.new{exit}
###################### Menu ###################
## Menu attached to root, file and help menu
menu_bar = TkMenu.new
root.menu(menu_bar)
file_menu = TkMenu.new(root)
helpMenu = TkMenu.new(root)
#_______________FILE MENU_______________
file_menu.add('command',
              'label'     => "New...",
              'command'   => newfile,
              'underline' => 0)
file_menu.add('command',
              'label'     => "OpenDir",
              'command'   => opendir,
              'underline' => 0)
file_menu.add('command',
              'label'     => "Exit",
              'command'   => exitapp,
              'underline' => 3)
#______________HELP MENU _________________________________
helpMenu.add('command',
              'label'   => "Help",
              'command' => proc{help_win},
              'underline' => 3)

#_________________________________________
menu_bar.add('cascade',
             'menu'  => file_menu,
             'label' => "Dir")
menu_bar.add('cascade',
             'menu' => helpMenu,
             'label' => "Help")

end
#____________________________________________________________
#The final and essential step, to run the mainloop for GUI to display
def self.show
Tk.mainloop
end

#________________ END OF CLASS _____________________

end